@@ -101,10 +101,11 @@ class Upbit:
             return result[0]
 
 
-    def get_balance(self, ticker="KRW", contain_req=False):
+    def get_balance(self, ticker="KRW", verbose=False, contain_req=False):
         """
         특정 코인/원화의 잔고를 조회하는 메소드
         :param ticker: 화폐를 의미하는 영문 대문자 코드
+        :param verbose: False: only the balance, True: original dictionary 
         :param contain_req: Remaining-Req 포함여부
         :return: 주문가능 금액/수량 (주문 중 묶여있는 금액/수량 제외)
         [contain_req == True 일 경우 Remaining-Req가 포함]
@@ -112,16 +113,20 @@ class Upbit:
         try:
             # fiat-ticker
             # KRW-BTC
+            fiat = "KRW"
             if '-' in ticker:
-                ticker = ticker.split('-')[1]
+                fiat, ticker = ticker.split('-')
 
             balances, req = self.get_balances(contain_req=True)
 
             # search the current currency
             balance = 0
             for x in balances:
-                if x['currency'] == ticker:
-                    balance = float(x['balance'])
+                if x['currency'] == ticker and x['unit_currency'] == fiat:
+                    if verbose is True:
+                        balance = x 
+                    else:
+                        balance = float(x['balance'])
                     break
 
             if contain_req:
@@ -448,12 +453,32 @@ class Upbit:
     #--------------------------------------------------------------------------
     # 출금
     #--------------------------------------------------------------------------
+    def get_withdraw_list(self, currency: str, contain_req=False):
+        """
+        출금 리스트 조회
+        :param currency: Currency 코드
+        :param contain_req: Remaining-Req 포함여부
+        :return:
+        """
+        try:
+            url = "https://api.upbit.com/v1/withdraws"
+            data = {"currency": currency}
+            headers = self._request_headers(data)
+
+            result = _send_get_request(url, headers=headers, data=data)
+            if contain_req:
+                return result
+            else:
+                return result[0]
+        except Exception as x:
+            print(x.__class__.__name__)
+            return None
+
     #     개별 출금 조회
     def get_individual_withdraw_order(self, uuid: str, currency: str, contain_req=False):
         """
-        현금 출금
+        개별 출금 조회
         :param uuid: 출금 UUID
-        :param txid: 출금 TXID
         :param currency: Currency 코드
         :param contain_req: Remaining-Req 포함여부
         :return:
@@ -528,7 +553,50 @@ class Upbit:
     # 입금 
     #--------------------------------------------------------------------------
     #     입금 리스트 조회 
+    def get_deposit_list(self, currency: str, contain_req=False):
+        """
+        입금 리스트 조회
+        :currency: Currency 코드
+        :param contain_req: Remaining-Req 포함여부
+        :return:
+        """
+        try:
+            url = "https://api.upbit.com//v1/deposits"
+            data = {"currency": currency}
+            headers = self._request_headers(data)
+
+            result = _send_get_request(url, headers=headers, data=data)
+            if contain_req:
+                return result
+            else:
+                return result[0]
+        except Exception as x:
+            print(x.__class__.__name__)
+            return None
+            
     #     개별 입금 조회
+    def get_individual_deposit_order(self, uuid: str, currency: str, contain_req=False):
+        """
+        개별 입금 조회
+        :param uuid: 입금 UUID
+        :param currency: Currency 코드
+        :param contain_req: Remaining-Req 포함여부
+        :return:
+        """
+        try:
+            url = "https://api.upbit.com/v1/deposit"
+            data = {"uuid": uuid, "currency": currency}
+            headers = self._request_headers(data)
+            result = _send_get_request(url, headers=headers, data=data)
+            if contain_req:
+                return result
+            else:
+                return result[0]
+        except Exception as x:
+            print(x.__class__.__name__)
+            return None
+
+
     #     입금 주소 생성 요청 
     #     전체 입금 주소 조회
     #     개별 입금 주소 조회
@@ -566,13 +634,18 @@ if __name__ == "__main__":
     #-------------------------------------------------------------------------
     # api key
     #-------------------------------------------------------------------------
-    with open("upbit.txt") as f:
-    #with open("조회전용키.txt") as f:
+    with open("../upbit.key") as f:
         lines = f.readlines()
         access = lines[0].strip()
         secret = lines[1].strip()
 
     upbit = Upbit(access, secret)
+    #print(upbit.get_balances())
+    print(upbit.get_balance("KRW-BTC", verbose=True))
+
+    # order 
+    resp = upbit.buy_limit_order("KRW-XRP", 500, 10)
+    print(resp)
 
 
     #-------------------------------------------------------------------------
@@ -623,5 +696,5 @@ if __name__ == "__main__":
     #pprint.pprint(resp)
 
     #     API키 리스트 조회
-    resp = upbit.get_api_key_list()
-    print(resp)
\ No newline at end of file
+    #resp = upbit.get_api_key_list()
+    #print(resp)
\ No newline at end of file
